"GetFitARMA" <-
function(y, p, q, pApprox=30, init=0){
#White noise case
if (p==0 && q==0) {
    LogL<-LoglikelihoodAR(0, y)
    ans<-list(loglikelihood=LogL, phiHat=numeric(0), thetaHat=numeric(0),convergence=0,algorithm="NID-exact")
    return(ans)
    }
if (length(init)==1 && init == 0) 
    xinit<-numeric(p+q) #handles both p+q>1 and p+q=1
else
    xinit<-init
if (length(xinit)!=p+q){
        message("GetARMAFit: init length not correct. Set to zero.")
        xinit<-numeric(p+q)
    }
if (max(abs(xinit))>0.99){
        message("GetARMAFit: init parameter setting outside (-0.99,0.99). Reset to 0.")
        xinit<-numeric(p+q)
    }

#Case p>0
#Use library FitAR function GetFitAR
if (p>0 && q==0) { #pure AR
    ans<-GetFitAR(y, 1:p)
    phiHat<-ans$phiHat
    convergence<-ans$convergence
    thetaHat<-numeric(0)
    loglikelihood<-ans$loglikelihood
    if (is.na(loglikelihood)) convergence <- -1
    alg <- ans$algorithm
}
else {#q>0 ARMA or MA
    n<-length(y)
    if (n < 30)
        warning("Series is too short for adequate likelihood approximation, need n>30.")  
    penaltyLoglikelihood<-(-length(y)/2*log(sum(y^2)/n))-10^4 
    #setup Champernowne matrix
    pApp <- pApprox
    if (n < 2*pApprox)
        pApp <- floor(n/2)    
    CD<-ChampernowneD(y,pApp,MeanZero=TRUE)
    
#ARMA case
    if (p>0 && q>0) {
    EntropyARMA<-function(x){
        if (max(abs(x))>0.99) 
         -penaltyLoglikelihood+max(abs(x))^2 
        else {
            zetaPhi=x[1:p]
            zetaTheta=x[(p+1):(p+q)]
            g<-TacvfARMA(PacfToAR(zetaPhi),PacfToAR(zetaTheta),pApp)
            xpar<-PacfDL(g, LinearPredictor=TRUE)$ARCoefficients
            -FastLoglikelihoodAR(xpar,n,CD)
        }
    }
    ans<-optim(xinit,EntropyARMA,method="L-BFGS-B", lower=rep(-0.99,p+q), upper=rep(0.99,p+q),
            control=list(trace=0))
    alg <- "L-BFGS-B"
    if(ans$convergence != 0  || max(abs(ans$par))>0.99) {#convergence problem. Use Nelder-Mead with penalty function
        alg<-"Nelder-Mead"
        ans<-optim(c(0,0),EntropyARMA,method="Nelder-Mead")
    }
    zpar<-ans$par
    phiHat<-PacfToAR(zpar[1:p])
    thetaHat<-PacfToAR(zpar[p+(1:q)])
    loglikelihood <- -(ans$value)
    convergence <- ans$convergence
    if (is.na(loglikelihood)) convergence <- -1
    }

#Pure MA Case
    if (p==0 && q>0) {
    phiHat<-numeric(0)
    EntropyARMA<-function(x){
        if (max(abs(x))>0.99) 
          -penaltyLoglikelihood 
        else {
        zetaTheta=x[1:q]
        g<-TacvfARMA(numeric(0),PacfToAR(zetaTheta),pApp)
        xpar<-PacfDL(g, LinearPredictor=TRUE)$ARCoefficients
        -FastLoglikelihoodAR(xpar,n,CD)
            }
        }
        if (q>1){ #higher order MA
            ans<-optim(xinit,EntropyARMA,method="L-BFGS-B", lower=rep(-0.99,p+q), upper=rep(0.99,p+q))
            alg<-"L-BFGS-B"
            if(ans$convergence != 0) {
                alg<-"Nelder-Mead"
                ans<-optim(xinit,EntropyARMA,method="Nelder-Mead")
            }
        zpar <- ans$par
        thetaHat <- PacfToAR(zpar[1:q])
        loglikelihood <- -(ans$value)
        convergence <- ans$convergence
        if (is.na(loglikelihood)) convergence <- -1
        }
        else {  #pure MA(1), use optimize
        ans <- optimize(EntropyARMA, interval=c(-1,1))
        convergence<-0
         thetaHat <- ans$minimum
        if (is.null(thetaHat) || is.na(thetaHat) || !is.numeric(thetaHat)){
            convergence <- -1
            }
        loglikelihood <- -(ans$objective)
        alg<-"optimize"    
            }
        }   
}
list(loglikelihood=loglikelihood, phiHat=phiHat, thetaHat=thetaHat, convergence=ans$convergence, 
     algorithm=alg)
}

