\name{GetFitARMA}
\alias{GetFitARMA}
\title{ Fit ARMA(p,q) model to mean zero time series. }
\description{
The algorithm of McLeod and Zhang (2007) is used.
}
\usage{
GetFitARMA(y, p, q, pApprox = 30, init = 0)
}
\arguments{
  \item{y}{ time series }
  \item{p}{ AR order }
  \item{q}{ MA order }
  \item{pApprox}{ initial AR approximation  }
  \item{init}{ initial parameter estimates }
}
\details{
  See McLeod and Zhang (2006).
  For AR(1), exact solution obtained via solving a cubic equation.
  For MA(1), \code{optimize} is used instead of \code{optim}.
  For valid likelihood computation, we need 2*pApprox >= length(y). So if the supplied
  value of pApprox does not satify this pApprox is set to length(n)/2.
  If pApprox is less than 30, a warning message is displayed.
}
\value{
  \item{loglikelihood}{value of maximized loglikelihood}
  \item{phiHat}{estimated phi parameters}
  \item{thetaHat}{estimated theta parameters}
  \item{convergence}{result from \code{optim} if used. Otherwise 0.}
  \item{algorithm}{ "L-BFGS-B" or "Nelder-Mead" or "optimize" or "cubic"} 
}

\references{
McLeod, A.I. and Zhang, Y. (2007, tentatively accepted).
Faster ARMA Maximum Likelihood Estimation.
Computational Statistics and Data Analysis. 
}

\author{ A.I. McLeod, aimcleod@uwo.ca }

\seealso{ 
\code{\link{arima}}, 
\code{\link{FitARMA}} 
}
\examples{
data(SeriesA)
z<-SeriesA-mean(SeriesA)
GetFitARMA(z, 1, 1)
w<-diff.ts(z, differences=1)
GetFitARMA(w, 0, 1)
  }
}
\keyword{ ts }
